package Facebook::Cookie;
BEGIN {
  $Facebook::Cookie::AUTHORITY = 'cpan:GETTY';
}
BEGIN {
  $Facebook::Cookie::VERSION = '0.102';
}
# ABSTRACT: DEPRECATED (replaced by Facebook::Signed)

use strict;
use warnings;


1;
__END__
=pod

=head1 NAME

Facebook::Cookie - DEPRECATED (replaced by Facebook::Signed)

=head1 VERSION

version 0.102

=head1 DESCRIPTION

B<THIS PACKAGE IS DEPRECATED!>

If you have code using this package, please switch to L<Facebook::Signed>.

=encoding utf8

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>

=item *

Frank Sheiness <syndesis@gmail.com>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Raudssus Social Software & Facebook Distribution Authors.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

